@@ -140,7 +140,8 @@ class Wsdl(WsdlBase):
                                 normal=('cl_install_autocheck_set',
                                         'cl_install_autocheck_interval',
                                         'cl_install_cleanpkg_set',
-                                        'cl_install_other_set'))],
+                                        'cl_install_other_set'),
+                                expert=('cl_install_update_pkg_set',))],
         # действие выводит информацию перед запуском
         'brief': {'next': __("Run"),
                   'image': 'finish',
